# Streamlit Notebook

> Like Jupyter Notebook, but inside Streamlit.


[![Open in Streamlit][share_badge]][share_link]

<img width="1497" alt="image" src="https://github.com/iamaziz/StBook/assets/3298308/c18671be-df86-4e78-a3c1-f734f2987361">


[share_badge]: https://static.streamlit.io/badges/streamlit_badge_black_white.svg
[share_link]: https://stbook.streamlit.app


### Install and run locally


Package installation (venv recommended)

```bash
pip install stbook
```

Start Streamlit Notebook

```bash
stbook
```

<hr>

### DEMOs



https://github.com/iamaziz/StBook/assets/3298308/210b536c-60b3-486e-921d-73c3c5f76cdc



<sub>NOTE: Copilot is running locally, not availabe in the deployed version.</sub>

https://github.com/iamaziz/StBook/assets/3298308/99ff3983-041e-4d74-ad6b-c1444aeeff0a



